==> nextcloud-22.2.6.tgz: nextcloud/apps/password_policy/l10n/bg.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Паролата е изтекла, моля, използвайте метода за забравена парола за възстановяване",
    "Password must not have been used recently before." : "Паролата не трябва да е била използвана наскоро.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Паролата е в топ 1 000 000 на най-ползваните. Моля изберете друга.",
    "Password is present in compromised password list. Please choose a different password." : "Паролата присъства в списъка с компрометирани пароли. Моля, изберете различна парола.",
    "Password needs to be at least %s characters long." : "Паролата трябва да е дълга поне %s знака.",
    "Password needs to contain at least one numeric character." : "Паролата трябва да съдържа поне едно число.",
    "Password needs to contain at least one special character." : "Паролата трябва да съдържа поне един специален символ.",
    "Password needs to contain at least one lower and one upper case character." : "Паролата трябва да съдържа поне една главна и една малка буква.",
    "Password policy" : "Политика за паролите",
    "Allows admins to configure a password policy" : "Позволява на администраторите да конфигурират политиката за парола",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Позволява на администратора да дефинира определени предварителни условия за парола, напр. налагат минимална дължина",
    "Saved" : "Запазено",
    "Minimum password length" : "Минимална дължина на паролата",
    "User password history" : "История на потребителската парола",
    "Number of days until user password expires" : "Брой дни до изтичане на паролата на потребителя",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Брой опити за влизане преди потребителският профил да се блокира (0 без ограничение)",
    "Forbid common passwords" : "Забранени са лесните пароли",
    "Enforce upper and lower case characters" : "Изискват се главни и малки букви",
    "Enforce numeric characters" : "Изискват се числа",
    "Enforce special characters" : "Изискват се специални символи",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Паролите се проверяват за присъствие в списъка на пароли изтекли в Интернет от haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Тази проверка създава хеш на паролата и изпраща първите 5 знака от този хеш към API на hasibeenpwned.com, за да извлече списък с всички хешове, които започват с тях. След това проверява на Nextcloud  екземпляра дали хешът на паролата е в набора от резултати.",
    "Unknown error" : "Неизвестна грешка",
    "Minimal length has to be a non negative number" : "Минималната дължина трябва да не е отрицателно число",
    "History size has to be a non negative number" : "Размерът на историята трябва да не е отрицателно число",
    "Expiration days have to be a non negative number" : "Срокът на  валидност не трябва да е отрицателно число",
    "Maximum login attempts have to be a non negative number" : "Максималният брой опити за влизане не трябва да е отрицателно число",
    "Password needs to be at least %s characters long" : "Паролата трябва да съдържа поне %s символа"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/password_policy/l10n/bg.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Паролата е изтекла, моля, използвайте метода за забравена парола за възстановяване",
    "Password must not have been used recently before." : "Паролата не трябва да е била използвана наскоро.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Паролата е в топ 1 000 000 на най-ползваните. Моля изберете друга.",
    "Password is present in compromised password list. Please choose a different password." : "Паролата присъства в списъка с компрометирани пароли. Моля, изберете различна парола.",
    "Password needs to be at least %s characters long." : "Паролата трябва да е дълга поне %s знака.",
    "Password needs to contain at least one numeric character." : "Паролата трябва да съдържа поне едно число.",
    "Password needs to contain at least one special character." : "Паролата трябва да съдържа поне един специален символ.",
    "Password needs to contain at least one lower and one upper case character." : "Паролата трябва да съдържа поне една главна и една малка буква.",
    "Password policy" : "Политика за паролите",
    "Allows admins to configure a password policy" : "Позволява на администраторите да конфигурират политиката за парола",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Позволява на администратора да дефинира определени предварителни условия за парола, напр. налагат минимална дължина",
    "Saved" : "Запазено",
    "Minimum password length" : "Минимална дължина на паролата",
    "User password history" : "История на потребителската парола",
    "Number of days until user password expires" : "Брой дни до изтичане на паролата на потребителя",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Брой опити за влизане преди потребителският профил да се блокира (0 без ограничение)",
    "Forbid common passwords" : "Забранени са лесните пароли",
    "Enforce upper and lower case characters" : "Изискват се главни и малки букви",
    "Enforce numeric characters" : "Изискват се числа",
    "Enforce special characters" : "Изискват се специални символи",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Паролите се проверяват за присъствие в списъка на пароли изтекли в Интернет от haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Тази проверка създава хеш на паролата и изпраща първите 5 знака от този хеш към API на hasibeenpwned.com, за да извлече списък с всички хешове, които започват с тях. След това проверява на Nextcloud  екземпляра дали хешът на паролата е в набора от резултати.",
    "Unknown error" : "Неизвестна грешка",
    "Minimal length has to be a non negative number" : "Минималната дължина трябва да не е отрицателно число",
    "History size has to be a non negative number" : "Размерът на историята трябва да не е отрицателно число",
    "Expiration days have to be a non negative number" : "Срокът на  валидност не трябва да е отрицателно число",
    "Maximum login attempts have to be a non negative number" : "Максималният брой опити за влизане не трябва да е отрицателно число",
    "Error while saving" : "Грешка при запазване"
},
"nplurals=2; plural=(n != 1);");
